@@ -684,9 +684,14 @@ void AdjustAfsPath (LPTSTR pszTarget, LPCTSTR pszSource, BOOL fWantAFS, BOOL fWa
       lstrcpy (pszTarget, (fWantAFS) ? TEXT("/afs") : TEXT(""));
    else if ((*pszSource != TEXT('/')) && (*pszSource != TEXT('\\')))
       wsprintf (pszTarget, TEXT("/afs/%s"), pszSource);
-   else if (fWantAFS && lstrncmpi (&pszSource[1], TEXT("afs"), 3))
+   // We don't want to strip afs off the start if it is part of something for example afscell.company.com
+   else if (fWantAFS && (lstrncmpi (&pszSource[1], TEXT("afs"), 3)) || !((pszSource[4] == TEXT('/')) ||
+                                                                         (pszSource[4] == TEXT('\\')) ||
+                                                                         (lstrlen(pszSource) == 4)))
       wsprintf (pszTarget, TEXT("/afs%s"), pszSource);
-   else if (!fWantAFS && !lstrncmpi (&pszSource[1], TEXT("afs"), 3))
+   else if (!fWantAFS && (!lstrncmpi (&pszSource[1], TEXT("afs"), 3) || ((pszSource[4] == TEXT('/')) ||
+                                                                        (pszSource[4] == TEXT('\\')) ||
+                                                                        (lstrlen(pszSource) == 4))))
       lstrcpy (pszTarget, &pszSource[4]);
    else
       lstrcpy (pszTarget, pszSource);
