@@ -13,7 +13,7 @@
 #include <assert.h>
 #include "lwp.h"
 
-#ifdef  AFS_OSF_ENV
+#if defined(AFS_OSF_ENV) || defined(AFS_S390_LINUX20_ENV)
 extern int PRE_Block;              /* used in lwp.c and process.s */
 #else
 extern char PRE_Block;             /* used in lwp.c and process.s */
@@ -35,6 +35,9 @@ extern char PRE_Block;             /* used in lwp.c and process.s */
 #define LWP_SP 0
 #elif   defined(AFS_I386_LINUX20_ENV)
 #define LWP_SP 4
+#elif   defined(AFS_S390_LINUX20_ENV)
+#define LWP_SP 9
+#define LWP_FP 5
 #elif   defined(AFS_SPARC_LINUX20_ENV)
 #define LWP_SP 0
 #define LWP_FP 1
@@ -105,7 +108,7 @@ char*	sp;
 				{
 				case 0: jmpBuffer = (jmp_buf_type *)jmp_tmp;
 					jmpBuffer[LWP_SP] = (jmp_buf_type)sp; 
-#if defined(AFS_SPARC_LINUX20_ENV) || (defined(AFS_SPARC64_LINUX20_ENV) && defined(AFS_32BIT_USR_ENV))
+#if defined(AFS_S390_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV) || (defined(AFS_SPARC64_LINUX20_ENV) && defined(AFS_32BIT_USR_ENV))
 					jmpBuffer[LWP_FP] = (jmp_buf_type)sp; 
 #endif
 				   	longjmp(jmp_tmp,1);
